@@ -7,7 +7,7 @@ from autoarray.util import mask_util
 
 class Convolver:
     def __init__(self, mask, kernel):
-        """ Class to setup the 1D convolution of an / util matrix.
+        """ Class to setup the 1D convolution of an / mapping matrix.
 
         Take a simple 3x3 and masks:
 
@@ -43,8 +43,8 @@ class Convolver:
         IxIxIxIxIxIxIxIxIxIxI
         IxIxIxIxIxIxIxIxIxIxI     This is an imaging.Mask2D, where:
         IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI     x = True (Pixel is masked and excluded from lens)
-        IxIxIxIoIoIoIxIxIxIxI     o = False (Pixel is not masked and included in lens)
+        IxIxIxIxIxIxIxIxIxIxI     x = `True` (Pixel is masked and excluded from lens)
+        IxIxIxIoIoIoIxIxIxIxI     o = `False` (Pixel is not masked and included in lens)
         IxIxIxIoIoIoIxIxIxIxI
         IxIxIxIoIoIoIxIxIxIxI
         IxIxIxIxIxIxIxIxIxIxI
@@ -107,7 +107,7 @@ class Convolver:
         Whilst the scheme above accounts for all blurred light within the masks, it does not account for the fact that \
         pixels outside of the masks will also blur light into it. This effect is accounted for using blurring frames.
 
-        It is omitted for util matrix blurring, as an inversion does not fit data outside of the masks.
+        It is omitted for mapping matrix blurring, as an inversion does not fit data outside of the masks.
 
         First, a blurring masks is computed from a masks, which describes all pixels which are close enough to the masks \
         to blur light into it for a given kernel size. Following the example above, the following blurring masks is \
@@ -116,8 +116,8 @@ class Convolver:
         IxIxIxIxIxIxIxIxIxIxI
         IxIxIxIxIxIxIxIxIxIxI     This is an example grid.Mask2D, where:
         IxIxIxIxIxIxIxIxIxIxI
-        IxIxIoIoIoIoIoIxIxIxI     x = True (Pixel is masked and excluded from lens)
-        IxIxIoIxIxIxIoIxIxIxI     o = False (Pixel is not masked and included in lens)
+        IxIxIoIoIoIoIoIxIxIxI     x = `True` (Pixel is masked and excluded from lens)
+        IxIxIoIxIxIxIoIxIxIxI     o = `False` (Pixel is not masked and included in lens)
         IxIxIoIxIxIxIoIxIxIxI
         IxIxIoIxIxIxIoIxIxIxI
         IxIxIoIoIoIoIoIxIxIxI
@@ -261,7 +261,8 @@ class Convolver:
     @staticmethod
     @decorator_util.jit()
     def frame_at_coordinates_jit(coordinates, mask, mask_index_array, kernel_2d):
-        """ Compute the frame (indexes of pixels light is blurred into) and kernel_frame (kernel kernel values of those \
+        """
+    Returns the frame (indexes of pixels light is blurred into) and kernel_frame (kernel kernel values of those \
         pixels) for a given coordinate in a masks and its PSF.
 
         Parameters
@@ -303,9 +304,9 @@ class Convolver:
 
         Parameters
         -----------
-        image : ndarray
+        image : np.ndarray
             1D array of the values which are to be blurred with the convolver's PSF.
-        blurring_image : ndarray
+        blurring_image : np.ndarray
             1D array of the blurring values which blur into the array after PSF convolution.
         """
 
@@ -373,9 +374,9 @@ class Convolver:
         return blurred_image_1d
 
     def convolve_mapping_matrix(self, mapping_matrix):
-        """For a given inversion util matrix, convolve every pixel's mapped with the PSF kernel.
+        """For a given inversion mapping matrix, convolve every pixel's mapped with the PSF kernel.
 
-        A util matrix provides non-zero entries in all elements which map two pixels to one another
+        A mapping matrix provides non-zero entries in all elements which map two pixels to one another
         (see *inversions.mappers*).
 
         For example, lets take an which is masked using a 'cross' of 5 pixels:
@@ -384,7 +385,7 @@ class Convolver:
         [[False, False, False]],
         [[ True, False,  True]]
 
-        As example util matrix of this cross is as follows (5 pixels x 3 source pixels):
+        As example mapping matrix of this cross is as follows (5 pixels x 3 source pixels):
 
         [1, 0, 0] [0->0]
         [1, 0, 0] [1->0]
@@ -426,8 +427,8 @@ class Convolver:
         [[0.0, 0.7, 0.7]],
         [[0.0, 0.0, 0.0]]
 
-        Finally, we map each of these blurred back to a blurred util matrix, which is analogous to the
-        util matrix.
+        Finally, we map each of these blurred back to a blurred mapping matrix, which is analogous to the
+        mapping matrix.
 
         [0.6, 0.0, 0.0] [0->0]
         [0.6, 0.0, 0.0] [1->0]
@@ -435,12 +436,12 @@ class Convolver:
         [0.0, 0.7, 0.0] [3->1]
         [0.0, 0.0, 0.6] [4->2]
 
-        If the util matrix is sub-gridded, we perform the convolution on the fractional surface brightnesses in an
+        If the mapping matrix is sub-gridded, we perform the convolution on the fractional surface brightnesses in an
         identical fashion to above.
 
         Parameters
         -----------
-        mapping_matrix : ndarray
+        mapping_matrix : np.ndarray
             The 2D mapping matrix describing how every inversion pixel maps to a pixel on the data pixel.
         """
         return self.convolve_matrix_jit(
