@@ -4,7 +4,7 @@ import autoarray.plot as aplt
 array = aa.Array.ones(shape_2d=(31, 31), pixel_scales=(1.0, 1.0), sub_size=2)
 array[0] = 3.0
 
-mask = aa.Mask.circular(
+mask = aa.Mask2D.circular(
     shape_2d=array.shape_2d,
     pixel_scales=array.pixel_scales,
     radius=5.0,
