@@ -2,6 +2,7 @@ from os import path
 import os
 import pytest
 
+from autoconf import conf
 import autoarray as aa
 import autoarray.plot as aplt
 
@@ -20,7 +21,7 @@ def make_imaging_plotter_setup():
 
 @pytest.fixture(autouse=True)
 def set_config_path():
-    aa.conf.instance = aa.conf.Config(
+    conf.instance = conf.Config(
         path.join(directory, "files/plotter"), path.join(directory, "output")
     )
 
